==> dwarfg_install_1.0.3.tgz: dwarfg_install/appdir/web/gui/src/Form/Device/DeviceNetDevicesType.php <==
<?php

namespace App\Form\Device;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

class DeviceNetDevicesType extends AbstractType
{

    /**
     * @param FormBuilderInterface $builder
     * @param array $options
     */
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {

        $netDevices = $options['data']['netDevices'];

        foreach ($netDevices as $netDevice){

            $builder
                ->add('cellular_' . $netDevice->getId(), CheckboxType::class, array(
                    'required' => false,
                    'label' => false,
                    'data' => ($netDevice->isCellular) ? true : false,
                ))
                ->add('linkable_' . $netDevice->getId(), CheckboxType::class, array(
                    'required' => false,
                    'label' => false,
                    'data' => ($netDevice->isLinkable) ? true : false,
                ));

        }

        $builder
            ->add('save', SubmitType::class, ['label' => 'Update Settings',
                'block_prefix' => 'modal_footer'])
        ;
    }

    /**
     * @param OptionsResolver $resolver
     */
    public function configureOptions(OptionsResolver $resolver): void
    {

        $resolver->setDefaults([
           // 'data_class' => OsVersion::class,
        ]);

    }

}

==> dwarfg_install_1.9.0.tgz: dwarfg_install/appdir/web/gui/src/Form/Device/DeviceNetDevicesType.php <==
<?php

namespace App\Form\Device;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

class DeviceNetDevicesType extends AbstractType
{

    /**
     * @param FormBuilderInterface $builder
     * @param array $options
     */
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {

        $netDevices = $options['data']['netDevices'];

        foreach ($netDevices as $netDevice){

            $builder
                ->add('cellular_' . $netDevice->getId(), CheckboxType::class, array(
                    'required' => false,
                    'label' => false,
                    'data' => ($netDevice->isCellular) ? true : false,
                ))
                ->add('linkable_' . $netDevice->getId(), CheckboxType::class, array(
                    'required' => false,
                    'label' => false,
                    'data' => ($netDevice->isLinkable) ? true : false,
                ));

        }

        $builder
            ->add('save', SubmitType::class, [
				'label' => 'Update Settings',
				'icon' => 'fas fa fa-refresh',
				'attr' => ['class' => 'btn-primary btn-sm'],
                'block_prefix' => 'modal_footer'])
        ;
    }

    /**
     * @param OptionsResolver $resolver
     */
    public function configureOptions(OptionsResolver $resolver): void
    {

        $resolver->setDefaults([
           // 'data_class' => OsVersion::class,
        ]);

    }

}
